==> identity-apps-1.0.117-source-release.zip: identity-apps-1.0.117/modules/i18n/src/translations/si-LK/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "ප්\u200Dරවේශය",
    active: "සක්\u200Dරීයයි",
    add: "එකතු කරන්න",
    all: "සියලුම",
    applicationName: "ඇප් එකේ නම",
    applications: "ඇප්ස්",
    approvalStatus: "අනුමත කිරීමේ තත්වය",
    approve: "අනුමත කරන්න",
    assignees: "පැවරුම්කරුවන්",
    browser: "බ්\u200Dරව්සරය",
    cancel: "අවලංගු කරන්න",
    challengeQuestionNumber: "අභියෝගාත්මක ප්\u200Dරශ්නය {{number}}",
    change: "වෙනස් කරන්න",
    claim: "හිමිකම",
    completed: "සම්පුර්ණ කරන ලද",
    configure: "වින්\u200Dයාස කරන්න",
    contains: "අඩංගු වේ",
    continue: "පවත්වාගෙන යන්න",
    createdOn: "නිර්මාණය කරන ලද්දේ",
    dangerZone: "අන්තරා කලාපය",
    delete: "මකන්න",
    description: "විස්තරය",
    deviceModel: "උපාංග ආකෘතිය",
    edit: "සංස්කරණය කරන්න",
    endsWith: "සමඟ අවසන් වේ",
    equals: "සමාන",
    filter: "පෙරහන",
    goBackHome: "නැවත ප්\u200Dරධාන පිටුවට",
    help: "උපකාර",
    hidePassword: "මුරපදය සඟවන්න",
    initiator: "ආරම්භකයා",
    ipAddress: "ip ලිපිනය",
    lastAccessed: "අවසන් ප්\u200Dරවේශය",
    lastSeen: "අවසන් වරට",
    loginTime: "පිවිසුම් කාලය",
    logout: "වරන්න",
    more: "තව",
    name: "නම",
    operatingSystem: "මෙහෙයුම් පද්ධතිය",
    operations: "මෙහෙයුම්",
    overview: "දළ විශ්ලේෂණය",
    personalInfo: "පෞද්ගලික තොරතුරු",
    priority: "ප්\u200Dරමුඛතාවය",
    privacy: "රහස්\u200Dයතාවය",
    properties: "ගුණාංග",
    ready: "සූදානම්",
    reject: "ප්\u200Dරතික්ෂේප කරන්න",
    release: "මුදා හැරීම",
    remove: "ඉවත් කරන්න",
    removeAll: "සියල්ල ඉවත් කරන්න",
    reserved: "වෙන් කරන ලද",
    resetFilters: "පෙරහන් නැවත සකසන්න",
    retry: "නැවත උත්සාහ කරන්න",
    revoke: "අවලංගු කරන්න",
    revokeAll: "සියල්ල අවලංගු කරන්න",
    save: "සුරකින්න",
    search: "සොයන්න",
    security: "ආරක්ෂාව",
    showAll: "සියල්ල පෙන්වන්න",
    showLess: "අඩුවෙන් පෙන්වන්න",
    showMore: "වැඩිදුර තොරතුරු",
    showPassword: "මුරපදය පෙන්වන්න",
    startsWith: "සමඟ ආරම්භ වේ",
    submit: "ඉදිරිපත් කරන්න",
    switch: "මාරු කරන්න",
    terminate: "අවසන් කරන්න",
    terminateAll: "සියල්ල අවසන් කරන්න",
    terminateSession: "සැසිය අවසන් කරන්න",
    type: "වර්ගය",
    update: "යාවත්කාලීන කරන්න",
    user: "පරිශීලක"
};

==> identity-apps-1.0.217-source-release.zip: identity-apps-1.0.217/modules/i18n/src/translations/si-LK/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "ප්\u200Dරවේශය",
    active: "සක්\u200Dරීයයි",
    add: "එකතු කරන්න",
    all: "සියලුම",
    applicationName: "ඇප් එකේ නම",
    applications: "ඇප්ස්",
    approvalStatus: "අනුමත කිරීමේ තත්වය",
    approve: "අනුමත කරන්න",
    assignees: "පැවරුම්කරුවන්",
    browser: "බ්\u200Dරව්සරය",
    cancel: "අවලංගු කරන්න",
    challengeQuestionNumber: "අභියෝගාත්මක ප්\u200Dරශ්නය {{number}}",
    change: "වෙනස් කරන්න",
    claim: "හිමිකම",
    close: "වසන්න",
    completed: "සම්පුර්ණ කරන ලද",
    configure: "වින්\u200Dයාස කරන්න",
    contains: "අඩංගු වේ",
    continue: "පවත්වාගෙන යන්න",
    createdOn: "නිර්මාණය කරන ලද්දේ",
    dangerZone: "අන්තරා කලාපය",
    delete: "මකන්න",
    description: "විස්තරය",
    deviceModel: "උපාංග ආකෘතිය",
    docs: "ලියකියවිලි",
    documentation: "ප්‍රලේඛනය",
    done: "සම්පූර්ණයි",
    download: "බාගත",
    edit: "සංස්කරණය කරන්න",
    endsWith: "සමඟ අවසන් වේ",
    equals: "සමාන",
    filter: "පෙරහන",
    goBackHome: "නැවත ප්\u200Dරධාන පිටුවට",
    help: "උපකාර",
    hidePassword: "මුරපදය සඟවන්න",
    identityProviders: "හැඳුනුම්පත් සපයන්නා",
    initiator: "ආරම්භකයා",
    ipAddress: "ip ලිපිනය",
    lastAccessed: "අවසන් ප්\u200Dරවේශය",
    lastSeen: "අවසන් වරට",
    loginTime: "පිවිසුම් කාලය",
    logout: "වරන්න",
    more: "තව",
    myAccount: "පුද්ගලික ගිණුම",
    name: "නම",
    operatingSystem: "මෙහෙයුම් පද්ධතිය",
    operations: "මෙහෙයුම්",
    overview: "දළ විශ්ලේෂණය",
    personalInfo: "පෞද්ගලික තොරතුරු",
    pin: "තබා ගන්න",
    pinned: "තබා ඇත",
    priority: "ප්\u200Dරමුඛතාවය",
    privacy: "රහස්\u200Dයතාවය",
    properties: "ගුණාංග",
    ready: "සූදානම්",
    reject: "ප්\u200Dරතික්ෂේප කරන්න",
    release: "මුදා හැරීම",
    remove: "ඉවත් කරන්න",
    removeAll: "සියල්ල ඉවත් කරන්න",
    reserved: "වෙන් කරන ලද",
    resetFilters: "පෙරහන් නැවත සකසන්න",
    retry: "නැවත උත්සාහ කරන්න",
    revoke: "අවලංගු කරන්න",
    revokeAll: "සියල්ල අවලංගු කරන්න",
    samples: "සාම්පල",
    save: "සුරකින්න",
    search: "සොයන්න",
    security: "ආරක්ෂාව",
    services: "සේවාවන්",
    sdks: "SDKs",
    showAll: "සියල්ල පෙන්වන්න",
    showLess: "අඩුවෙන් පෙන්වන්න",
    showMore: "වැඩිදුර තොරතුරු",
    showPassword: "මුරපදය පෙන්වන්න",
    startsWith: "සමඟ ආරම්භ වේ",
    submit: "ඉදිරිපත් කරන්න",
    switch: "මාරු කරන්න",
    technologies: "තාක්ෂණයන්",
    terminate: "අවසන් කරන්න",
    terminateAll: "සියල්ල අවසන් කරන්න",
    terminateSession: "සැසිය අවසන් කරන්න",
    type: "වර්ගය",
    unpin: "ඉවත් කරන්න",
    unpinned: "ඉවත් කරන ලදි",
    update: "යාවත්කාලීන කරන්න",
    user: "පරිශීලක",
    verify: "සත්‍යාපනය කරන්න"
};
